@@ -8,7 +8,7 @@
 
 # ** Total scores summary table ######
 totalscores_table_Input <- reactive({
-  sc <- scored_test()
+  sc <- total_score()
 
   tab <- t(data.table(c(min(sc, na.rm = T),
                         max(sc, na.rm = T),
@@ -32,35 +32,32 @@ include.colnames = T
 
 # ** Histogram of total scores ######
 totalscores_histogram_Input<- reactive({
-  a <- test_answers()
-  k <- test_key()
-  sc <- scored_test()
-
+  sc <- total_score()
   bin <- as.numeric(input$slider_totalscores_histogram)
 
-  df <- data.table(sc,
+  df <- data.table(score = sc,
                    gr = cut(sc,
-                            breaks = unique(c(0, bin - 1, bin, ncol(a))),
+                            breaks = unique(c(0, bin - 1, bin, ncol(binary()))),
                             include.lowest = T))
 
-  if (bin < min(sc, na.rm = T)){
+  if (bin < min(total_score(), na.rm = T)){
     col <- "blue"
   } else {
-    if (bin == min(sc, na.rm = T)){
+    if (bin == min(total_score(), na.rm = T)){
       col <- c("grey", "blue")
     } else {
       col <- c("red", "grey", "blue")
     }
   }
 
-  ggplot(df, aes(x = sc)) +
+  ggplot(df, aes(x = score)) +
     geom_histogram(aes(fill = gr), binwidth = 1, color = "black") +
     scale_fill_manual("", breaks = df$gr, values = col) +
     labs(x = "Total score",
          y = "Number of respondents") +
     scale_y_continuous(expand = c(0, 0),
-                       limits = c(0, max(table(sc)) + 0.01 * nrow(a))) +
-    scale_x_continuous(limits = c(-0.5, ncol(a) + 0.5)) +
+                       limits = c(0, max(table(sc)) + 0.01 * nrow(binary()))) +
+    scale_x_continuous(limits = c(-0.5, ncol(binary()) + 0.5)) +
     theme_app()
 })
 
@@ -76,9 +73,10 @@ output$DB_totalscores_histogram <- downloadHandler(
   },
   content = function(file) {
     ggsave(file, plot = totalscores_histogram_Input() +
-             theme(text = element_text(size = 10)),
+             theme(text = element_text(size = setting_figures$text_size)),
            device = "png",
-           height = 4, width = 8, dpi = 300)
+           height = setting_figures$height, width = setting_figures$width,
+           dpi = setting_figures$dpi)
   }
 )
 
@@ -88,18 +86,16 @@ output$DB_totalscores_histogram <- downloadHandler(
 
 # ** Table for scores ######
 scores_tables_Input <- reactive({
-  a  <- test_answers()
-  k  <- test_key()
-  sc <- scored_test()
+  sc <- total_score()
 
   # total score
   tosc <- sort(unique(sc))
   # percentile
   perc <- cumsum(prop.table(table(sc)))
   # succes rate
-  sura <- (tosc / length(k)) * 100
+  sura <- (tosc / length(key())) * 100
   # Z score
-  zsco <- sort(unique(scale(sc)))
+  zsco <- sort(unique(z_score()))
   # T score
   tsco <- 50 + 10 * zsco
 
@@ -114,3 +110,14 @@ output$scores_tables <- renderTable({
   scores_tables_Input()
 },
 include.rownames = FALSE)
+
+# ** Download table with standard scores ** ####
+output$download_standard_scores <- downloadHandler(
+  filename = function() {
+    paste("Standard_scores", ".csv", sep = "")
+  },
+  content = function(file) {
+    data <- scores_tables_Input()
+    write.csv(data, file)
+  }
+)
