@@ -8,28 +8,80 @@
 
 # ** Polychoric correlation matrix ######
 corr_structure <- reactive({
-  data <- correct_answ()
+  data <- binary()
 
-  corP <- polychoric(data)
+  # calculate correlations depending on selected method
+  if (input$type_of_corr == 'spearman') {
+    corP <- cor(data, method = 'spearman')
+  } else if (input$type_of_corr == 'pearson') {
+    corP <- cor(data, method = 'pearson')
+  } else if (input$type_of_corr == 'polychoric') {
+    corP <- polychoric(data)
+    corP <- corP$rho
+  }
   corP
 })
 
 # ** Correlation plot ######
 corr_plot_Input <- reactive({
   corP <- corr_structure()
-  corP <- corP$rho
+
   tlcex <- max(ifelse(dim(corP)[1] < 30, 1, 0.9 - (dim(corP)[1] - 30)*0.05), 0.5)
 
   numclust <- input$corr_plot_clust
   clustmethod <- input$corr_plot_clustmethod
 
-  if (clustmethod == "none"){
-    corrplot(corP, tl.cex = tlcex)
-  } else {
-    corrplot(corP, tl.cex = tlcex, order = "hclust", hclust.method = clustmethod, addrect = numclust)
+  # option to display correlation values
+  if(input$show_corr %% 2 == 1 ) {
+    updateActionButton(session, "show_corr", label = "Hide correlation values")
+	  if (clustmethod == "none"){
+	    corrplot(corP, tl.cex = tlcex, tl.pos = 'lt', method = 'number',
+	             number.cex = 0.7, col = 'black', cl.pos = 'n')
+    } else {
+      corrplot(corP, tl.cex = tlcex, order = "hclust", hclust.method = clustmethod,
+               addrect = numclust, tl.pos = 'lt', method = 'number',
+               number.cex  = 0.7, col = 'black', cl.pos = 'n')
+    }
+   } else {
+      updateActionButton(session,"show_corr", label = "Display correlation values")
+    if (clustmethod == "none"){
+	    corrplot(corP, tl.cex = tlcex, tl.pos = 'lt')
+	  } else {
+	    corrplot(corP, tl.cex = tlcex, order = "hclust", hclust.method = clustmethod,
+	             addrect = numclust, tl.pos = 'lt')
+	  }
   }
 })
 
+corr_plot_Input_report <- reactive({
+  corP <- corr_structure()
+
+  tlcex <- max(ifelse(dim(corP)[1] < 30, 1, 0.9 - (dim(corP)[1] - 30)*0.05), 0.5)
+
+  numclust <- ifelse(input$customizeCheck, input$corr_plot_clust_report, input$corr_plot_clust)
+  clustmethod <- ifelse(input$customizeCheck, input$corr_plot_clustmethod_report, input$corr_plot_clustmethod)
+
+  # option to display correlation values
+  if(input$show_corr %% 2 == 1 ) {
+    updateActionButton(session, "show_corr", label = "Hide correlation values")
+    if (clustmethod == "none"){
+      corrplot(corP, tl.cex = tlcex, tl.pos = 'lt', method = 'number',
+               number.cex = 0.7, col = 'black', cl.pos = 'n')
+    } else {
+      corrplot(corP, tl.cex = tlcex, order = "hclust", hclust.method = clustmethod,
+               addrect = numclust, tl.pos = 'lt', method = 'number',
+               number.cex  = 0.7, col = 'black', cl.pos = 'n')
+    }
+  } else {
+    updateActionButton(session,"show_corr", label = "Display correlation values")
+    if (clustmethod == "none"){
+      corrplot(corP, tl.cex = tlcex, tl.pos = 'lt')
+    } else {
+      corrplot(corP, tl.cex = tlcex, order = "hclust", hclust.method = clustmethod,
+               addrect = numclust, tl.pos = 'lt')
+    }
+  }
+})
 
 # ** Output correlation plot ######
 output$corr_plot <- renderPlot({
@@ -44,26 +96,107 @@ output$DB_corr_plot <- downloadHandler(
   content = function(file) {
     # in corrplot this must be plotted completely again!
     corP <- corr_structure()
-    corP <- corP$rho
+
     tlcex <- max(ifelse(dim(corP)[1] < 30, 1, 0.9 - (dim(corP)[1] - 30)*0.05), 0.5)
 
     numclust <- input$corr_plot_clust
     clustmethod <- input$corr_plot_clustmethod
 
-    png(file, height = 800, width = 800, res = 400, pointsize = 300/72)
+    png(file, height = setting_figures$height, width = setting_figures$height,
+        units = "in",
+        res = setting_figures$dpi,
+        pointsize = setting_figures$dpi/72)
     if (clustmethod == "none"){
       corrplot(corP, tl.cex = tlcex)
     } else {
-      corrplot(corP, tl.cex = tlcex, order = "hclust", hclust.method = clustmethod, addrect = numclust)
+      corrplot(corP, tl.cex = tlcex, order = "hclust", hclust.method = clustmethod,
+               addrect = numclust)
     }
     dev.off()
   }
 )
 
+
+output$corr_matrix <- downloadHandler(
+	filename = function() {
+		paste("Correlation_matrix", ".csv", sep = "")
+	},
+	content = function(file) {
+	  corP <- corr_structure()
+	  write.csv(corP, file)
+	})
+
+# ** Dendrogram ######
+dendrogram_plot_Input <- reactive({
+  corP <- corr_structure()
+  dist <- as.dist(1 - corP)
+
+  clustmethod <- input$corr_plot_clustmethod
+  numclust <- input$corr_plot_clust
+
+  hc <- hclust(dist, method = clustmethod)
+
+  if (numclust == 1){
+    order <- hc$order
+    label <- hc$labels[hc$order]
+    times <- length(label)
+  } else {
+    plot(hc)
+    rhc <- rect.hclust(hc, k = numclust)
+    order <- unlist(rhc)
+    label <- names(order)
+    times <- sapply(rhc, length)
+  }
+
+  df <- data.frame(label = label,
+                   num = order,
+                   cluster = rep(paste("Cluster", 1:numclust), times))
+  dendr <- dendro_data(hc, type = "rectangle")
+  dfd <- merge(dendr$labels, df, by = "label")
+
+  ggplot() +
+    geom_segment(data = segment(dendr),
+                 aes(x = x, y = y, xend = xend, yend = yend)) +
+    geom_text(data = dfd,
+              aes(x = x, y = y, label = label, hjust = 0, color = cluster)) +
+    coord_flip() + scale_y_reverse(expand = c(0.2, 0)) +
+    ylab("Height") +
+    theme_app() +
+    theme(axis.line.y = element_blank(),
+          axis.ticks.y = element_blank(),
+          axis.text.y = element_blank(),
+          axis.title.y = element_blank())
+})
+
+# ** Output scree plot ######
+output$dendrogram_plot <- renderPlot({
+  dendrogram_plot_Input()
+})
+
+# ** DB scree plot ######
+output$DB_dendrogram <- downloadHandler(
+  filename =  function() {
+    paste("fig_Dendrogram.png", sep = "")
+  },
+  content = function(file) {
+    ggsave(file, plot = dendrogram_plot_Input() +
+             theme(text = element_text(size = setting_figures$text_size)),
+           device = "png",
+           height = setting_figures$height, width = setting_figures$width,
+           dpi = setting_figures$dpi)
+  }
+)
+
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+# * FACTOR ANALYSIS ######
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
 # ** Scree plot ######
 scree_plot_Input <- reactive({
   corP <- corr_structure()
-  ev <- eigen(corP$rho)$values
+
+  ev <- eigen(corP)$values
+
   df <- data.table(pos = 1:length(ev), ev)
 
   ggplot(data = df, aes(x = pos, y = ev)) +
@@ -85,9 +218,11 @@ output$DB_scree_plot <- downloadHandler(
     paste("fig_ScreePlot.png", sep = "")
   },
   content = function(file) {
-    ggsave(file, plot = scree_plot_Input() + theme(text = element_text(size = 10)),
+    ggsave(file, plot = scree_plot_Input() +
+             theme(text = element_text(size = setting_figures$text_size)),
            device = "png",
-           height = 4, width = 8, dpi = 300)
+           height = setting_figures$height, width = setting_figures$width,
+           dpi = setting_figures$dpi)
   }
 )
 
@@ -97,8 +232,8 @@ output$DB_scree_plot <- downloadHandler(
 
 # ** Validity boxplot ######
 validity_plot_boxplot_Input <- reactive({
-  ts <- scored_test()
-  cv <- unlist(criterion_variable())
+  ts <- total_score()
+  cv <- unlist(criterion())
 
   df <- data.table(ts, cv)
   df <- df[complete.cases(df), ]
@@ -116,8 +251,8 @@ validity_plot_boxplot_Input <- reactive({
 
 # ** Validity scatterplot ######
 validity_plot_scatter_Input <- reactive({
-  ts <- scored_test()
-  cv <- unlist(criterion_variable())
+  ts <- total_score()
+  cv <- unlist(criterion())
 
   size <- as.factor(cv)
   levels(size) <- table(cv)
@@ -142,7 +277,7 @@ validity_plot_scatter_Input <- reactive({
 
 # ** Validity descriptive plot ######
 validity_plot_Input <- reactive({
-  cv <- criterion_variable()
+  cv <- criterion()
 
   ## this is fixed value to recognize discrete variable
   k <- 6
@@ -162,23 +297,24 @@ output$validity_plot <- renderPlot({
 # ** DB validity descriptive plot ######
 output$DB_validity_plot <- downloadHandler(
   filename =  function() {
-    cv <- criterion_variable()
+    cv <- criterion()
     k <- 6
     type <- ifelse(length(unique(cv)) <= length(cv)/k, "boxplot", "scatterplot")
     paste("fig_CriterionVariable_", type, ".png", sep = "")
   },
   content = function(file) {
     ggsave(file, plot = validity_plot_Input() +
-             theme(text = element_text(size = 10)),
+             theme(text = element_text(size = setting_figures$text_size)),
            device = "png",
-           height = 4, width = 8, dpi = 300)
+           height = setting_figures$height, width = setting_figures$width,
+           dpi = setting_figures$dpi)
   }
 )
 
 # ** Validity correlation table ######
 validity_table_Input <- reactive({
-  ts <- scored_test()
-  cv <- criterion_variable()
+  ts <- total_score()
+  cv <- criterion()
 
   ct <- cor.test(ts, cv, method = "spearman", exact = F)
   tab <- c(round(ct$estimate, 2), round(ct$statistic, 2), round(ct$p.value, 3))
@@ -218,7 +354,7 @@ output$validity_table_interpretation <- renderUI({
 
 # ** Validity distractor text ######
 output$validity_distractor_text <- renderUI({
-  cv <- criterion_variable()
+  cv <- criterion()
 
   ## this is fixed value to recognize discrete variable
   k <- 6
@@ -244,10 +380,10 @@ output$validity_distractor_text <- renderUI({
 
 # ** Validity distractors plot ######
 validity_distractor_plot_Input <- reactive({
-  a <- test_answers()
-  k <- test_key()
+  a <- nominal()
+  k <- key()
   i <- input$validitydistractorSlider
-  cv <- criterion_variable()
+  cv <- criterion()
   num.group <- input$validity_group
 
   multiple.answers <- c(input$type_validity_combinations_distractor == "Combinations")
@@ -269,16 +405,18 @@ output$DB_validity_distractor_plot <- downloadHandler(
     paste("fig_DistractorsValidityPlot.png", sep = "")
   },
   content = function(file) {
-    ggsave(file, plot = validity_distractor_plot_Input() + theme(text = element_text(size = 10)),
+    ggsave(file, plot = validity_distractor_plot_Input() +
+             theme(text = element_text(size = setting_figures$text_size)),
            device = "png",
-           height = 4, width = 8, dpi = 300)
+           height = setting_figures$height, width = setting_figures$width,
+           dpi = setting_figures$dpi)
   }
 )
 
 # ** Validity correlation table for items ######
 validity_table_item_Input <- reactive({
-  correct <- correct_answ()
-  cv <- criterion_variable()
+  correct <- binary()
+  cv <- criterion()
   i <- input$validitydistractorSlider
 
   ct <- cor.test(unlist(correct[, i, with = F]), cv, method = "spearman", exact = F)
